## This script runs through all wav files in a given directory.
## It will only loop through those files beginning with a user-specified string
## (leave blank to loop through all files). 
##
## Each wav file and corresponding TextGrid will be opened for annotation.
## If the wav file does not have a corresponding TextGrid, a new one will be created. 
##
## TextGrids are saved after editing - this means that old TGs will be overwritten.
##
## jessamyn.schertz@gmail.com
## August 23, 2015

clearinfo

## The following opens a dialog box at the beginning to query user input

beginPause: "User Input"
	comment: "This is the directory where the sound files and TGs live:"
	word: "datadir", "data/"
	comment: "I will only pay attention to files starting with the following (leave blank to loop through all files)"
	word: "beginsWith", "pr"
clicked = endPause: "Continue", 1

if right$(datadir$, 1) != "/"
	datadir$ = datadir$+"/"
endif

files = Create Strings as file list: "fileList", datadir$+beginsWith$+"*.wav"
num_words = Get number of strings
for word_index from 1 to num_words
	select files
	filename$ = Get string: word_index
	filename$ = filename$ - ".wav"
	sound = Read from file: datadir$+filename$+".wav"

	## See if TextGrid exists
	tgpath$ = datadir$ + filename$ + ".TextGrid"

	## If not, open them up for editing
	if not fileReadable(tgpath$)
		tg = To TextGrid: "phones", ""
	else
		tg = Read from file: tgpath$
	endif
	plus sound
	View & Edit
	editor TextGrid 'filename$'
		beginPause: "Annotate"
		clicked = endPause: "Continue", 1
		Close
	endeditor
	select tg
	Save as text file: datadir$+filename$+".TextGrid"
	plus sound
	Remove
endfor